@@ -15,11 +15,13 @@ from typeddfs._entries import (
     ChecksumMapping,
     Checksums,
     CompressionFormat,
+    ExampleDfs,
     FileFormat,
     FinalDf,
     FrozeDict,
     FrozeList,
     FrozeSet,
+    LazyDf,
     MatrixDf,
     TypedDf,
     TypedDfs,
