@@ -9,13 +9,33 @@ from typing import Optional, Set, Union
 
 from typeddfs._core_dfs import CoreDf
 from typeddfs._mixins._full_io_mixin import _FullIoMixin
-from typeddfs.df_errors import NonStrColumnError
+from typeddfs.df_errors import (
+    HashEntryExistsError,
+    HashFileExistsError,
+    NonStrColumnError,
+)
+from typeddfs.df_typing import DfTyping
 from typeddfs.file_formats import FileFormat
 from typeddfs.utils import Utils
 from typeddfs.utils.checksums import Checksums
 
 
 class AbsDf(_FullIoMixin, CoreDf):
+    @classmethod
+    def read_url(cls, url: str) -> __qualname__:
+        """
+        Reads from a URL, guessing the format from the filename extension.
+        Delegates to the ``read_*`` functions of this class.
+
+        See Also:
+            :meth:`read_file`
+
+        Returns:
+            An instance of this class
+        """
+        df = cls._call_read(cls, url)
+        return cls._convert_typed(df)
+
     @classmethod
     def read_file(
         cls,
@@ -55,6 +75,11 @@ class AbsDf(_FullIoMixin, CoreDf):
             - .flexwf (fixed-but-unspecified-width with an optional delimiter)
             - .txt, .lines, or .list
 
+        See Also:
+            :meth:`read_url`
+            :meth:`write_file`
+
+
         Args:
             path: Only path-like strings or pathlib objects are supported, not buffers
                   (because we need a filename).
@@ -69,8 +94,13 @@ class AbsDf(_FullIoMixin, CoreDf):
         Returns:
             An instance of this class
         """
-        path = Path(path)
-        t = cls.get_typing()
+        if any((str(path).startswith(x + "://") for x in ["http", "https", "ftp"])):
+            # just save some pain -- better than a weird error in .resolve()
+            raise ValueError(f"Cannot read from URL {path}; use read_url instead")
+        path = Path(path).resolve()
+        t: DfTyping = cls.get_typing()
+        if attrs is None:
+            attrs = t.io.use_attrs
         cs = Checksums(alg=t.io.hash_algorithm)
         cs.verify_any(path, file_hash=file_hash, dir_hash=dir_hash, computed=hex_hash)
         df = cls._call_read(cls, path)
@@ -91,7 +121,7 @@ class AbsDf(_FullIoMixin, CoreDf):
         attrs: Optional[bool] = None,
     ) -> Optional[str]:
         """
-        Writes to a file (or possibly URL), guessing the format from the filename extension.
+        Writes to a file, guessing the format from the filename extension.
         Delegates to the ``to_*`` functions of this class (e.g. ``to_csv``).
         Only includes file formats that can be read back in with corresponding ``to`` methods.
 
@@ -112,6 +142,9 @@ class AbsDf(_FullIoMixin, CoreDf):
             - .pkl and .pickle
             - .txt, .lines, or .list; see :meth:`to_lines` and :meth:`read_lines`
 
+        See Also:
+            :meth:`read_file`
+
         Args:
             path: Only path-like strings or pathlib objects are supported, not buffers
                   (because we need a filename).
@@ -136,7 +169,10 @@ class AbsDf(_FullIoMixin, CoreDf):
             InvalidDfError: If the DataFrame is not valid for this type
             ValueError: If the type of a column or index name is non-str
         """
-        path = Path(path)
+        if any((str(path).startswith(x + "://") for x in ["http", "https", "ftp"])):
+            # just save some pain -- better than a weird error in .resolve()
+            raise ValueError(f"Cannot write to URL {path}")
+        path = Path(path).resolve()
         t = self.__class__.get_typing()
         file_hash = file_hash is True or file_hash is None and t.io.file_hash
         dir_hash = dir_hash is True or dir_hash is None and t.io.dir_hash
@@ -151,13 +187,13 @@ class AbsDf(_FullIoMixin, CoreDf):
             if path.exists():
                 raise FileExistsError(f"File {path} already exists")
             if file_hash and file_hash_path.exists():
-                raise FileExistsError(f"{file_hash_path} already exists")
+                raise HashFileExistsError(f"{file_hash_path} already exists")
             if dir_hash_path.exists():
                 dir_sums = Checksums(alg=t.io.hash_algorithm).load_dirsum_exact(dir_hash_path)
                 if path in dir_sums:
-                    raise FileExistsError(f"Path {path} listed in {dir_hash_path}")
+                    raise HashEntryExistsError(f"Path {path} listed in {dir_hash_path}")
             if file_hash and file_hash_path.exists():
-                raise FileExistsError(f"{file_hash_path} already exists")
+                raise HashFileExistsError(f"{file_hash_path} already exists")
             if attrs and attrs_path.exists():
                 raise FileExistsError(f"{attrs_path} already exists")
         self._check(self)
